@@ -3,11 +3,10 @@ extern crate proc_macro;
 use proc_macro::TokenStream;
 use quote::quote;
 use syn::parse::{Parse, ParseStream};
-use syn::{parenthesized, parse, parse2, DeriveInput, Generics, Ident, Result};
+use syn::{parenthesized, parse, parse2, DeriveInput, Ident, Result};
 
 struct ContextType {
     name: Ident,
-    generics: Generics,
 }
 
 impl Parse for ContextType {
@@ -17,7 +16,6 @@ impl Parse for ContextType {
 
         Ok(ContextType {
             name: content.parse()?,
-            generics: content.parse()?,
         })
     }
 }
@@ -44,26 +42,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
     let context_type_name = &context_type.name;
 
-    let mut impl_generics_container = context_type.generics.clone();
-    impl_generics_container.params.clear();
-    impl_generics_container
-        .params
-        .push(syn::parse_quote!('common));
-
-    let mut ty_generics_container = context_type.generics.clone();
-    ty_generics_container.params.clear();
-
-    for _ in context_type.generics.lifetimes() {
-        ty_generics_container
-            .params
-            .push(syn::parse_quote!('common));
-    }
-
-    let (impl_generics, _, _) = impl_generics_container.split_for_impl();
-    let (_, ty_generics, _) = ty_generics_container.split_for_impl();
-    let common_lifetime_def = syn::LifetimeDef::new(syn::parse_quote!('common));
-    let common_lifetime = common_lifetime_def.lifetime;
-
     let gen = quote! {
         mod checkout_server {
             pub use std::sync::Arc;
@@ -445,7 +423,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn initiate_payment_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<Option<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>>,
+                body: TypedBody<Option<<super::#context_type_name as PaymentProcessor>::ProcessArgs>>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
@@ -481,7 +459,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn initiate_order_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<Option<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>>,
+                body: TypedBody<Option<<super::#context_type_name as PaymentProcessor>::ProcessArgs>>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
@@ -523,11 +501,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn step_payment_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>,
+                body: TypedBody<<super::#context_type_name as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name<'static> as PaymentProcessor>::PrivateData,
-                <super::#context_type_name<'static> as PaymentProcessor>::PublicData,
-                <super::#context_type_name<'static> as PaymentProcessor>::ProcessArgs
+                <super::#context_type_name as PaymentProcessor>::PrivateData,
+                <super::#context_type_name as PaymentProcessor>::PublicData,
+                <super::#context_type_name as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
@@ -568,11 +546,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn callback_payment_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<CorrelationIdParam>,
-                body: TypedBody<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>,
+                body: TypedBody<<super::#context_type_name as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name<'static> as PaymentProcessor>::PrivateData,
-                <super::#context_type_name<'static> as PaymentProcessor>::PublicData,
-                <super::#context_type_name<'static> as PaymentProcessor>::ProcessArgs
+                <super::#context_type_name as PaymentProcessor>::PrivateData,
+                <super::#context_type_name as PaymentProcessor>::PublicData,
+                <super::#context_type_name as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
@@ -614,9 +592,9 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
             ) -> Result<HttpResponseOk<Payment<
-                <super::#context_type_name<'static> as PaymentProcessor>::PrivateData,
-                <super::#context_type_name<'static> as PaymentProcessor>::PublicData,
-                <super::#context_type_name<'static> as PaymentProcessor>::ProcessArgs
+                <super::#context_type_name as PaymentProcessor>::PrivateData,
+                <super::#context_type_name as PaymentProcessor>::PublicData,
+                <super::#context_type_name as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
                 let mut ctx = req_ctx
@@ -646,7 +624,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
         }
 
         #[async_trait]
-        impl #impl_generics checkout_server::Server<#common_lifetime, #context_type_name #ty_generics> for #server_type_name {
+        impl checkout_server::Server<#context_type_name> for #server_type_name {
             type Context = checkout_server::ServerContext;
 
             fn api_description() -> checkout_server::ApiDescription<checkout_server::ServerContext> {
